==> scc-3.1.0.tar.gz: scc-3.1.0/LANGUAGES.md <==
```
ABAP (abap)
ActionScript (as)
Ada (ada,adb,ads,pad)
Agda (agda)
Alchemist (crn)
Alex (x)
Alloy (als)
Android Interface Definition Language (aidl)
APL (apl,aplf,apln,aplc,dyalog)
AppleScript (applescript)
Arvo (avdl,avpr,avsc)
AsciiDoc (adoc)
ASP (asa,asp)
ASP.NET (asax,ascx,asmx,aspx,master,sitemap,webinfo)
Assembly (s,asm)
ATS (dats,sats,ats,hats)
Autoconf (in)
AutoHotKey (ahk)
AWK (awk)
bait (bait)
BASH (bash,bash_login,bash_logout,bash_profile,bashrc,.bash_login,.bash_logout,.bash_profile,.bashrc)
Basic (bas)
Batch (bat,btm,cmd)
Bazel (bzl,build.bazel,build,workspace)
Bitbake (bb,bbappend,bbclass)
Bitbucket Pipeline (bitbucket-pipelines.yml)
Blade template (blade.php)
Boo (boo)
Bosque (bsq)
Brainfuck (bf)
BuildStream (bst)
C (c,ec,pgc)
C Header (h)
C Shell (csh,.cshrc)
C# (cs,csx)
C++ (cc,cpp,cxx,c++,pcc,ino)
C++ Header (hh,hpp,hxx,inl,ipp)
Cabal (cabal)
Cassius (cassius)
Ceylon (ceylon)
Clojure (clj,cljc)
ClojureScript (cljs)
Closure Template (soy)
CloudFormation (JSON) (json)
CloudFormation (YAML) (yaml,yml)
CMake (cmake,cmakelists.txt)
COBOL (cob,cbl,ccp,cobol,cpy)
CodeQL (ql,qll)
CoffeeScript (coffee)
Cogent (cogent)
ColdFusion (cfm)
ColdFusion CFScript (cfc)
Coq (v)
Creole (creole)
Crystal (cr)
CSS (css)
CSV (csv)
Cython (pyx,pxi,pxd)
D (d)
Dart (dart)
Device Tree (dts,dtsi)
Dhall (dhall)
DM (dm)
Docker ignore (.dockerignore)
Dockerfile (dockerfile,dockerfile)
Document Type Definition (dtd)
DOT (dot,gv)
Elixir (ex,exs)
Elm (elm)
Emacs Dev Env (ede)
Emacs Lisp (el)
Erlang (erl,hrl)
Expect (exp)
Extensible Stylesheet Language Transformations (xslt,xsl)
F# (fs,fsi,fsx,fsscript)
F* (fst)
Fennel (fnl)
FIDL (fidl)
Fish (fish)
Flow9 (flow)
Forth (4th,forth,fr,frt,fth,f83,fb,fpm,e4,rx,ft)
FORTRAN Legacy (f,for,ftn,f77,pfo)
FORTRAN Modern (f03,f08,f90,f95)
Fragment Shader File (fsh)
Freemarker Template (ftl)
Futhark (fut)
FXML (fxml)
Game Maker Language (gml)
Game Maker Project (yyp)
GDScript (gd)
Gemfile (gemfile)
Gherkin Specification (feature)
gitignore (.gitignore)
GLSL (vert,tesc,tese,geom,frag,comp)
GN (gn,gni)
Go (go)
Go Template (tmpl,gohtml,gotxt)
Gradle (gradle)
Groovy (groovy,grt,gtpl,gvy)
HAML (haml)
Hamlet (hamlet)
Handlebars (hbs,handlebars)
Happy (y,ly)
Haskell (hs)
Haxe (hx)
HEX (hex)
hoon (hoon)
HTML (html,htm)
IDL (idl,webidl,widl)
Idris (idr,lidr)
ignore (.ignore)
Intel HEX (ihex)
Isabelle (thy)
Jade (jade)
JAI (jai)
Janet (janet)
Java (java)
JavaScript (js,mjs)
JavaServer Pages (jsp)
Jenkins Buildfile (jenkinsfile)
Jinja (jinja,j2,jinja2)
JSON (json)
JSONL (jsonl)
JSX (jsx)
Julia (jl)
Julius (julius)
Jupyter (ipynb,jpynb)
Just (justfile)
K (k)
Korn Shell (ksh,.kshrc)
Kotlin (kt,kts)
LaTeX (tex)
LD Script (lds)
Lean (lean,hlean)
LESS (less)
LEX (l)
License (license,licence,copying,copying3,unlicense,unlicence,license-mit,licence-mit,copyright)
Lisp (lisp,lsp)
LLVM IR (ll)
LOLCODE (lol,lols)
Lua (lua)
Lucius (lucius)
Luna (luna)
m4 (m4)
Macromedia eXtensible Markup Language (mxml)
Madlang (mad)
Makefile (makefile,mak,mk,bp,makefile)
Mako (mako,mao)
Markdown (md,markdown)
MATLAB (m)
Meson (meson.build,meson_options.txt)
Modula3 (m3,mg,ig,i3)
Module-Definition (def)
Monkey C (mc)
MQL Header (mqh)
MQL4 (mq4)
MQL5 (mq5)
MSBuild (csproj,vbproj,fsproj,props,targets)
MUMPS (mps)
Mustache (mustache)
Nial (ndf)
Nim (nim)
Nix (nix)
Nushell (nu)
nuspec (nuspec)
Objective C (m)
Objective C++ (mm)
OCaml (ml,mli)
Opalang (opa)
Org (org)
Oz (oz)
Pascal (pas)
Patch (patch)
Perl (pl,pm)
PHP (php)
PKGBUILD (pkgbuild)
PL/SQL (fnc,pkb,pks,prc,trg,vw)
Plain Text (text,txt)
Polly (polly)
Pony (pony)
Powershell (ps1,psm1)
Processing (pde)
Prolog (p,pro)
Properties File (properties)
Protocol Buffers (proto)
PSL Assertion (psl)
Puppet (pp)
PureScript (purs)
Python (py)
Q# (qs)
QCL (qcl)
QML (qml)
R (r)
Racket (rkt)
Rakefile (rake,rakefile)
Razor (cshtml,razor)
ReasonML (re,rei)
Report Definition Language (rdl)
ReStructuredText (rst)
Robot Framework (robot)
Ruby (rb)
Ruby HTML (rhtml,erb)
Rust (rs)
SAS (sas)
Sass (sass,scss)
Scala (sc,scala)
Scheme (scm,ss)
Scons (csig,sconstruct,sconscript)
sed (sed)
Shell (sh,.tcshrc)
Sieve (sieve)
SKILL (il)
Smarty Template (tpl)
SNOBOL (sno)
Softbridge Basic (sbl)
Solidity (sol)
SPDX (spdx)
Specman e (e)
Spice Netlist (ckt)
SQL (sql,dml,ddl,dql)
SRecode Template (srt)
Standard ML (SML) (sml)
Stata (do,ado)
Stylus (styl)
Svelte (svelte)
SVG (svg)
Swift (swift)
Swig (i)
Systemd (automount,device,link,mount,path,scope,service,slice,socket,swap,target,timer)
SystemVerilog (sv,svh)
TaskPaper (taskpaper)
TCL (tcl)
Teal (teal)
Terraform (tf,tf.json)
TeX (tex,sty)
Thrift (thrift)
TL (tl)
TOML (toml)
Twig Template (twig)
TypeScript (ts,tsx)
TypeScript Typings (d.ts)
Unreal Script (uc,uci,upkg)
Ur/Web (ur,urs)
Ur/Web Project (urp)
V (v)
Vala (vala)
Varnish Configuration (vcl)
Verilog (vg,vh,v)
Verilog Args File (irunargs,xrunargs)
Vertex Shader File (vsh)
VHDL (vhd,vhdl)
Vim Script (vim,vimrc,gvimrc,_vimrc,.vimrc,_gvimrc,.gvimrc,vimrc,gvimrc)
Visual Basic (vb)
Visual Basic for Applications (cls)
Vue (vue)
Web Services Description Language (wsdl)
Wolfram (nb,wl)
Wren (wren)
XAML (xaml)
Xcode Config (xcconfig)
XML (xml)
XML Schema (xsd)
Xtend (xtend)
YAML (yaml,yml)
Yarn (yarn)
Zig (zig)
Zsh (zsh,zshenv,zlogin,zlogout,zprofile,zshrc,.zshenv,.zlogin,.zlogout,.zprofile,.zshrc)
```

==> scc-3.3.2.tar.gz: scc-3.3.2/LANGUAGES.md <==
```
ABAP (abap)
ActionScript (as)
Ada (ada,adb,ads,pad)
Agda (agda)
Alchemist (crn)
Alex (x)
Alloy (als)
Android Interface Definition Language (aidl)
APL (apl,aplf,apln,aplc,dyalog)
AppleScript (applescript)
Arturo (art)
AsciiDoc (adoc)
ASP (asa,asp)
ASP.NET (asax,ascx,asmx,aspx,master,sitemap,webinfo)
Assembly (s,asm)
ATS (dats,sats,ats,hats)
Autoconf (in)
AutoHotKey (ahk)
Avro (avdl,avpr,avsc)
AWK (awk)
bait (bt)
BASH (bash,bash_login,bash_logout,bash_profile,bashrc,.bash_login,.bash_logout,.bash_profile,.bashrc)
Basic (bas)
Batch (bat,btm,cmd)
Bazel (bzl,build.bazel,build,workspace)
Bicep (bicep)
Bitbake (bb,bbappend,bbclass)
Bitbucket Pipeline (bitbucket-pipelines.yml)
Blade template (blade.php)
Boo (boo)
Bosque (bsq)
Brainfuck (bf)
BuildStream (bst)
C (c,ec,pgc)
C Header (h)
C Shell (csh,.cshrc)
C# (cs,csx)
C++ (cc,cpp,cxx,c++,pcc,ino)
C++ Header (hh,hpp,hxx,inl,ipp)
Cabal (cabal)
Cairo (cairo)
Cassius (cassius)
Ceylon (ceylon)
Clojure (clj,cljc)
ClojureScript (cljs)
Closure Template (soy)
CloudFormation (JSON) (json)
CloudFormation (YAML) (yaml,yml)
CMake (cmake,cmakelists.txt)
COBOL (cob,cbl,ccp,cobol,cpy)
CodeQL (ql,qll)
CoffeeScript (coffee)
Cogent (cogent)
ColdFusion (cfm)
ColdFusion CFScript (cfc)
Coq (v)
Creole (creole)
Crystal (cr)
CSS (css)
CSV (csv)
Cuda (cu)
Cython (pyx,pxi,pxd)
D (d)
Dart (dart)
Device Tree (dts,dtsi)
Dhall (dhall)
DM (dm)
Docker ignore (.dockerignore)
Dockerfile (dockerfile,dockerfile)
Document Type Definition (dtd)
DOT (dot,gv)
Elixir (ex,exs)
Elm (elm)
Emacs Dev Env (ede)
Emacs Lisp (el)
Erlang (erl,hrl)
Expect (exp)
Extensible Stylesheet Language Transformations (xslt,xsl)
F# (fs,fsi,fsx,fsscript)
F* (fst)
Factor (factor)
Fennel (fnl)
FIDL (fidl)
Fish (fish)
Flow9 (flow)
Forth (4th,forth,fr,frt,fth,f83,fb,fpm,e4,rx,ft)
FORTRAN Legacy (f,for,ftn,f77,pfo)
FORTRAN Modern (f03,f08,f90,f95)
Fragment Shader File (fsh)
Freemarker Template (ftl)
FSL (fsl)
Futhark (fut)
FXML (fxml)
Game Maker Language (gml)
Game Maker Project (yyp)
GDScript (gd)
Gemfile (gemfile)
Gherkin Specification (feature)
gitignore (.gitignore)
GLSL (vert,tesc,tese,geom,frag,comp)
GN (gn,gni)
Go (go)
Go Template (tmpl,gohtml,gotxt)
Gradle (gradle)
GraphQL (graphql)
Groovy (groovy,grt,gtpl,gvy)
HAML (haml)
Hamlet (hamlet)
Handlebars (hbs,handlebars)
Happy (y,ly)
Hare (ha)
Haskell (hs)
Haxe (hx)
HEX (hex)
hoon (hoon)
HTML (html,htm)
IDL (idl,webidl,widl)
Idris (idr,lidr)
ignore (.ignore)
INI (ini)
Intel HEX (ihex)
Isabelle (thy)
Jade (jade)
JAI (jai)
Janet (janet)
Java (java)
JavaScript (js,mjs)
JavaServer Pages (jsp)
Jenkins Buildfile (jenkinsfile)
Jinja (jinja,j2,jinja2)
JSON (json)
JSONC (jsonc)
JSONL (jsonl)
Jsonnet (jsonnet,libsonnet)
JSX (jsx)
Julia (jl)
Julius (julius)
Jupyter (ipynb,jpynb)
Just (justfile)
K (k)
Korn Shell (ksh,.kshrc)
Kotlin (kt,kts)
LaTeX (tex)
LD Script (lds)
Lean (lean,hlean)
LESS (less)
LEX (l)
License (license,licence,copying,copying3,unlicense,unlicence,license-mit,licence-mit,copyright)
Lisp (lisp,lsp)
LLVM IR (ll)
LOLCODE (lol,lols)
Lua (lua)
Luau (luau)
Lucius (lucius)
Luna (luna)
m4 (m4)
Macromedia eXtensible Markup Language (mxml)
Madlang (mad)
Makefile (makefile,mak,mk,bp,makefile,gnumakefile)
Mako (mako,mao)
Markdown (md,markdown)
MATLAB (m)
MDX (mdx)
Meson (meson.build,meson_options.txt)
Modula3 (m3,mg,ig,i3)
Module-Definition (def)
Monkey C (mc)
MQL Header (mqh)
MQL4 (mq4)
MQL5 (mq5)
MSBuild (csproj,vbproj,fsproj,vcproj,vcxproj,vcxproj.filters,ilproj,myapp,props,rdlc,resx,settings,sln,targets)
MUMPS (mps)
Mustache (mustache)
Nial (ndf)
Nim (nim)
Nix (nix)
Nushell (nu)
nuspec (nuspec)
Objective C (m)
Objective C++ (mm)
OCaml (ml,mli)
Odin (odin)
Opalang (opa)
Org (org)
Oz (oz)
Pascal (pas)
Patch (patch)
Perl (pl,pm)
PHP (php)
Picat (pi)
PKGBUILD (pkgbuild)
Pkl (pkl)
PL/SQL (fnc,pkb,pks,prc,trg,vw)
Plain Text (text,txt)
Polly (polly)
Pony (pony)
Powershell (ps1,psm1)
Processing (pde)
Prolog (p,pro)
Properties File (properties)
Protocol Buffers (proto)
PRQL (prql)
PSL Assertion (psl)
Puppet (pp)
PureScript (purs)
Python (py)
Q# (qs)
QCL (qcl)
QML (qml)
R (r)
Racket (rkt)
Rakefile (rake,rakefile)
Raku (raku,rakumod,rakutest,rakudoc,t)
Razor (cshtml,razor)
ReasonML (re,rei)
Report Definition Language (rdl)
ReScript (res,resi)
ReStructuredText (rst)
Robot Framework (robot)
Ruby (rb)
Ruby HTML (rhtml,erb)
Rust (rs)
SAS (sas)
Sass (sass,scss)
Scala (sc,scala)
Scheme (scm,ss)
Scons (csig,sconstruct,sconscript)
sed (sed)
Shell (sh,.tcshrc)
Sieve (sieve)
SKILL (il)
Smarty Template (tpl)
SNOBOL (sno)
Softbridge Basic (sbl)
Solidity (sol)
SPDX (spdx)
Specman e (e)
Spice Netlist (ckt)
SQL (sql,dml,ddl,dql)
SRecode Template (srt)
Standard ML (SML) (sml)
Stata (do,ado)
Stylus (styl)
Svelte (svelte)
SVG (svg)
Swift (swift)
Swig (i)
Systemd (automount,device,link,mount,path,scope,service,slice,socket,swap,target,timer)
SystemVerilog (sv,svh)
TaskPaper (taskpaper)
TCL (tcl)
Teal (teal)
Templ (templ)
TemplateToolkit (tt,tt2)
Terraform (tf,tf.json)
TeX (tex,sty)
Textile (textile)
Thrift (thrift)
TL (tl)
TOML (toml)
Twig Template (twig)
TypeScript (ts,tsx)
TypeScript Typings (d.ts)
TypeSpec (tsp)
Unreal Script (uc,uci,upkg)
Ur/Web (ur,urs)
Ur/Web Project (urp)
V (v)
Vala (vala)
Varnish Configuration (vcl)
Verilog (vg,vh,v)
Verilog Args File (irunargs,xrunargs)
Vertex Shader File (vsh)
VHDL (vhd,vhdl)
Vim Script (vim,vimrc,gvimrc,_vimrc,.vimrc,_gvimrc,.gvimrc,vimrc,gvimrc)
Visual Basic (vb)
Visual Basic for Applications (cls)
Vue (vue)
Web Services Description Language (wsdl)
Windows Resource-Definition Script (rc)
Wolfram (nb,wl)
Wren (wren)
XAML (xaml)
Xcode Config (xcconfig)
XML (xml)
XML Schema (xsd)
Xtend (xtend)
YAML (yaml,yml)
Yarn (yarn)
Zig (zig)
Zsh (zsh,zshenv,zlogin,zlogout,zprofile,zshrc,.zshenv,.zlogin,.zlogout,.zprofile,.zshrc)
```
